[![Build Status](https://travis-ci.org/efortner/tunepy.svg?branch=master)](https://travis-ci.org/efortner/tunepy)
[![Coverage Status](https://coveralls.io/repos/github/efortner/tunepy/badge.svg?branch=master)](https://coveralls.io/github/efortner/tunepy?branch=master)
# tunepy2
Provides a variety of extensible and easy to use bitstring optimizers. 
